@@ -145,7 +145,7 @@ char  		 *ext_cmd = NULL;
 void
 usage (void)
 {
-	printf ("Usage:\n" "%s [--version] [--help]\n", MyName);
+  printf ("Usage:\n" "%s [-f [config file]] [-v|--version] [-h|--help]\n", MyName);
 	exit (0);
 }
 
@@ -166,7 +166,6 @@ main (int argc, char **argv)
 {
 	int           i;
 	char         *global_config_file = NULL;
-	char         *display_name = NULL;
 
 	/* Save our program name - for error messages */
 	SetMyName (argv[0]);
